riftsaw SVN: r309 - trunk/distribution/src/main/assembly.
by riftsaw-commits@lists.jboss.org
Author: heiko.braun(a)jboss.com
Date: 2009-11-24 07:21:00 -0500 (Tue, 24 Nov 2009)
New Revision: 309
Modified:
trunk/distribution/src/main/assembly/bin.xml
Log:
Correctly reference riftsaw-engine directory in assembly script
Modified: trunk/distribution/src/main/assembly/bin.xml
===================================================================
--- trunk/distribution/src/main/assembly/bin.xml 2009-11-24 12:10:56 UTC (rev 308)
+++ trunk/distribution/src/main/assembly/bin.xml 2009-11-24 12:21:00 UTC (rev 309)
@@ -96,7 +96,7 @@
<!-- Short term fix as dependency on riftsaw-utils is not being resolved,
so copy from BPEL war instead -->
<fileSet>
- <directory>../runtime/engine-assembly/target/riftsaw-2.0-M2/lib</directory>
+ <directory>../runtime/engine-assembly/target/riftsaw-engine/lib</directory>
<outputDirectory>/samples/common/lib</outputDirectory>
<includes>
<include>riftsaw-utils-*.jar</include>
15 years, 3 months
riftsaw SVN: r308 - trunk/runtime/engine-assembly.
by riftsaw-commits@lists.jboss.org
Author: heiko.braun(a)jboss.com
Date: 2009-11-24 07:10:56 -0500 (Tue, 24 Nov 2009)
New Revision: 308
Modified:
trunk/runtime/engine-assembly/pom.xml
Log:
remove remaining M2 references
Modified: trunk/runtime/engine-assembly/pom.xml
===================================================================
--- trunk/runtime/engine-assembly/pom.xml 2009-11-24 11:38:14 UTC (rev 307)
+++ trunk/runtime/engine-assembly/pom.xml 2009-11-24 12:10:56 UTC (rev 308)
@@ -123,8 +123,8 @@
<phase>package</phase>
<configuration>
<tasks>
- <delete file="${basedir}/target/riftsaw-2.0-M2/META-INF/jboss-service.xml"/>
- <delete file="${basedir}/target/riftsaw-2.0-M2/lib/geronimo-transaction-2.0.1.jar"/>
+ <delete file="${basedir}/target/riftsaw-engine/META-INF/jboss-service.xml"/>
+ <delete file="${basedir}/target/riftsaw-engine/lib/geronimo-transaction-2.0.1.jar"/>
</tasks>
</configuration>
<goals>
15 years, 3 months
riftsaw SVN: r307 - in trunk/runtime/engine-assembly/src/main/resources: META-INF and 1 other directory.
by riftsaw-commits@lists.jboss.org
Author: heiko.braun(a)jboss.com
Date: 2009-11-24 06:38:14 -0500 (Tue, 24 Nov 2009)
New Revision: 307
Added:
trunk/runtime/engine-assembly/src/main/resources/bpel-ds.xml
Removed:
trunk/runtime/engine-assembly/src/main/resources/META-INF/bpel-ds.xml
Log:
Keep bpel-ds.xml in sar directory, opposed to META-INF
Deleted: trunk/runtime/engine-assembly/src/main/resources/META-INF/bpel-ds.xml
===================================================================
--- trunk/runtime/engine-assembly/src/main/resources/META-INF/bpel-ds.xml 2009-11-24 11:31:14 UTC (rev 306)
+++ trunk/runtime/engine-assembly/src/main/resources/META-INF/bpel-ds.xml 2009-11-24 11:38:14 UTC (rev 307)
@@ -1,24 +0,0 @@
-<?xml version="1.0" encoding="UTF-8"?>
-
-
-<datasources>
- <local-tx-datasource>
- <jndi-name>BPELDB</jndi-name>
- <connection-url>jdbc:h2:${jboss.server.data.dir}${/}h2${/}BPELDB</connection-url>
- <driver-class>org.h2.Driver</driver-class>
- <user-name>sa</user-name>
- <password/>
- <transaction-isolation>TRANSACTION_READ_COMMITTED</transaction-isolation>
- <min-pool-size>5</min-pool-size>
- <max-pool-size>20</max-pool-size>
- <idle-timeout-minutes>0</idle-timeout-minutes>
- <prepared-statement-cache-size>32</prepared-statement-cache-size>
- <depends>jboss:service=h2,database=BPELDB</depends>
- </local-tx-datasource>
- <mbean code="org.jboss.soa.bpel.runtime.db.H2Database"
- name="jboss:service=h2,database=BPELDB">
- <attribute name="Database">BPELDB</attribute>
- <attribute name="DataDir">${jboss.server.data.dir}</attribute>
- </mbean>
-
-</datasources>
Copied: trunk/runtime/engine-assembly/src/main/resources/bpel-ds.xml (from rev 306, trunk/runtime/engine-assembly/src/main/resources/META-INF/bpel-ds.xml)
===================================================================
--- trunk/runtime/engine-assembly/src/main/resources/bpel-ds.xml (rev 0)
+++ trunk/runtime/engine-assembly/src/main/resources/bpel-ds.xml 2009-11-24 11:38:14 UTC (rev 307)
@@ -0,0 +1,24 @@
+<?xml version="1.0" encoding="UTF-8"?>
+
+
+<datasources>
+ <local-tx-datasource>
+ <jndi-name>BPELDB</jndi-name>
+ <connection-url>jdbc:h2:${jboss.server.data.dir}${/}h2${/}BPELDB</connection-url>
+ <driver-class>org.h2.Driver</driver-class>
+ <user-name>sa</user-name>
+ <password/>
+ <transaction-isolation>TRANSACTION_READ_COMMITTED</transaction-isolation>
+ <min-pool-size>5</min-pool-size>
+ <max-pool-size>20</max-pool-size>
+ <idle-timeout-minutes>0</idle-timeout-minutes>
+ <prepared-statement-cache-size>32</prepared-statement-cache-size>
+ <depends>jboss:service=h2,database=BPELDB</depends>
+ </local-tx-datasource>
+ <mbean code="org.jboss.soa.bpel.runtime.db.H2Database"
+ name="jboss:service=h2,database=BPELDB">
+ <attribute name="Database">BPELDB</attribute>
+ <attribute name="DataDir">${jboss.server.data.dir}</attribute>
+ </mbean>
+
+</datasources>
15 years, 3 months
riftsaw SVN: r306 - trunk/runtime/engine/src/main/java/org/jboss/soa/bpel/runtime/ws.
by riftsaw-commits@lists.jboss.org
Author: heiko.braun(a)jboss.com
Date: 2009-11-24 06:31:14 -0500 (Tue, 24 Nov 2009)
New Revision: 306
Modified:
trunk/runtime/engine/src/main/java/org/jboss/soa/bpel/runtime/ws/DeploymentBuilder.java
Log:
Filter WSDL artifacts
Modified: trunk/runtime/engine/src/main/java/org/jboss/soa/bpel/runtime/ws/DeploymentBuilder.java
===================================================================
--- trunk/runtime/engine/src/main/java/org/jboss/soa/bpel/runtime/ws/DeploymentBuilder.java 2009-11-24 11:30:45 UTC (rev 305)
+++ trunk/runtime/engine/src/main/java/org/jboss/soa/bpel/runtime/ws/DeploymentBuilder.java 2009-11-24 11:31:14 UTC (rev 306)
@@ -67,8 +67,17 @@
// any related artifact as well (brute force, I know)
File parent = wsdl.getParentFile();
assert parent.isDirectory();
- for(File f : parent.listFiles())
+
+ FileFilter filter = new FileFilter()
{
+ public boolean accept(File f)
+ {
+ return (f.getName().endsWith(".wsdl") || f.getName().endsWith(".xsd"));
+ }
+ };
+
+ for(File f : parent.listFiles(filter))
+ {
if(f.equals(wsdl)) continue;
copy(f, new File(this.wsdlDir, f.getName()));
}
15 years, 3 months
riftsaw SVN: r305 - in trunk: runtime/engine-assembly and 1 other directory.
by riftsaw-commits@lists.jboss.org
Author: heiko.braun(a)jboss.com
Date: 2009-11-24 06:30:45 -0500 (Tue, 24 Nov 2009)
New Revision: 305
Modified:
trunk/distribution/src/main/assembly/bin.xml
trunk/runtime/engine-assembly/pom.xml
Log:
Include riftsaw.sar in distro
Modified: trunk/distribution/src/main/assembly/bin.xml
===================================================================
--- trunk/distribution/src/main/assembly/bin.xml 2009-11-24 00:03:08 UTC (rev 304)
+++ trunk/distribution/src/main/assembly/bin.xml 2009-11-24 11:30:45 UTC (rev 305)
@@ -62,7 +62,7 @@
</fileSet>
<fileSet>
- <directory>../runtime/engine-assembly/target/riftsaw-2.0-M2/</directory>
+ <directory>../runtime/engine-assembly/target/riftsaw-engine/</directory>
<outputDirectory>/modules/riftsaw.sar</outputDirectory>
</fileSet>
Modified: trunk/runtime/engine-assembly/pom.xml
===================================================================
--- trunk/runtime/engine-assembly/pom.xml 2009-11-24 00:03:08 UTC (rev 304)
+++ trunk/runtime/engine-assembly/pom.xml 2009-11-24 11:30:45 UTC (rev 305)
@@ -100,6 +100,7 @@
</dependencies>
<build>
+ <finalName>riftsaw-engine</finalName>
<plugins>
<plugin>
<groupId>org.codehaus.mojo</groupId>
15 years, 3 months
riftsaw SVN: r304 - trunk/samples/quickstart/purchase/bpel.
by riftsaw-commits@lists.jboss.org
Author: alex.guizar(a)jboss.com
Date: 2009-11-23 19:03:08 -0500 (Mon, 23 Nov 2009)
New Revision: 304
Modified:
trunk/samples/quickstart/purchase/bpel/purchase.bpel
trunk/samples/quickstart/purchase/bpel/purchase.bpelex
Log:
[RIFTSAW-34] remove extraneous variable declaration
Modified: trunk/samples/quickstart/purchase/bpel/purchase.bpel
===================================================================
--- trunk/samples/quickstart/purchase/bpel/purchase.bpel 2009-11-23 17:38:28 UTC (rev 303)
+++ trunk/samples/quickstart/purchase/bpel/purchase.bpel 2009-11-24 00:03:08 UTC (rev 304)
@@ -22,7 +22,6 @@
<bpws:variables>
<bpws:variable messageType="lns:POMessage" name="PO" />
<bpws:variable messageType="lns:InvMessage" name="Invoice" />
- <bpws:variable messageType="lns:orderFaultType" name="POFault" />
<bpws:variable messageType="lns:shippingRequestMessage" name="shippingRequest" />
<bpws:variable messageType="lns:shippingInfoMessage" name="shippingInfo" />
<bpws:variable messageType="lns:scheduleMessage" name="shippingSchedule" />
Modified: trunk/samples/quickstart/purchase/bpel/purchase.bpelex
===================================================================
--- trunk/samples/quickstart/purchase/bpel/purchase.bpelex 2009-11-23 17:38:28 UTC (rev 303)
+++ trunk/samples/quickstart/purchase/bpel/purchase.bpelex 2009-11-24 00:03:08 UTC (rev 304)
@@ -21,10 +21,6 @@
<extensionObject xsi:type="org.eclipse.bpel.ui.uiextensionmodel:VariableExtension"/>
</extensions>
<extensions>
- <extendedObject href="purchase.bpel#//@variables/(a)children.5"/>
- <extensionObject xsi:type="org.eclipse.bpel.ui.uiextensionmodel:VariableExtension"/>
- </extensions>
- <extensions>
<extendedObject href="purchase.bpel#//@activity"/>
<extensionObject xsi:type="org.eclipse.bpel.ui.uiextensionmodel:ActivityExtension"/>
</extensions>
@@ -106,6 +102,6 @@
</extensions>
<extensions>
<extendedObject href="purchase.bpel#/"/>
- <extensionObject xsi:type="org.eclipse.bpel.ui.uiextensionmodel:ProcessExtension" modificationStamp="1258410536000"/>
+ <extensionObject xsi:type="org.eclipse.bpel.ui.uiextensionmodel:ProcessExtension" modificationStamp="1258765723000"/>
</extensions>
</extensionmodel:ExtensionMap>
15 years, 3 months
riftsaw SVN: r303 - in trunk/runtime: engine/src/main/java/org/jboss/soa/bpel/runtime/engine/ode and 2 other directories.
by riftsaw-commits@lists.jboss.org
Author: objectiser
Date: 2009-11-23 12:38:28 -0500 (Mon, 23 Nov 2009)
New Revision: 303
Removed:
trunk/runtime/engine/src/main/java/org/jboss/soa/bpel/runtime/engine/BPELFault.java
Modified:
trunk/runtime/engine/src/main/java/org/jboss/soa/bpel/runtime/engine/BPELEngine.java
trunk/runtime/engine/src/main/java/org/jboss/soa/bpel/runtime/engine/PartnerChannel.java
trunk/runtime/engine/src/main/java/org/jboss/soa/bpel/runtime/engine/ode/BPELEngineImpl.java
trunk/runtime/engine/src/main/java/org/jboss/soa/bpel/runtime/ws/WebServiceClient.java
trunk/runtime/jbossesb-bpel/src/test/java/org/jboss/soa/esb/actions/bpel/BPELInvokeTest.java
trunk/runtime/jbossesb-bpel/src/test/java/org/jboss/soa/esb/actions/bpel/TestBPELEngine.java
Log:
Remove BPELFault as no longer required to pass a fault across the BPELEngine interface. Now it is up to the InvocationAdapter implementation to record the fault details from the ODE Message Exchange.
Modified: trunk/runtime/engine/src/main/java/org/jboss/soa/bpel/runtime/engine/BPELEngine.java
===================================================================
--- trunk/runtime/engine/src/main/java/org/jboss/soa/bpel/runtime/engine/BPELEngine.java 2009-11-23 16:52:29 UTC (rev 302)
+++ trunk/runtime/engine/src/main/java/org/jboss/soa/bpel/runtime/engine/BPELEngine.java 2009-11-23 17:38:28 UTC (rev 303)
@@ -39,10 +39,9 @@
/**
*
* @param invocationAdapter
- * @throws BPELFault
* @throws Exception
*/
- public void invoke(InvocationAdapter invocationAdapter) throws BPELFault, Exception;
+ public void invoke(InvocationAdapter invocationAdapter) throws Exception;
/**
* This method closes the BPEL engine.
Deleted: trunk/runtime/engine/src/main/java/org/jboss/soa/bpel/runtime/engine/BPELFault.java
===================================================================
--- trunk/runtime/engine/src/main/java/org/jboss/soa/bpel/runtime/engine/BPELFault.java 2009-11-23 16:52:29 UTC (rev 302)
+++ trunk/runtime/engine/src/main/java/org/jboss/soa/bpel/runtime/engine/BPELFault.java 2009-11-23 17:38:28 UTC (rev 303)
@@ -1,70 +0,0 @@
-/*
- * JBoss, Home of Professional Open Source
- * Copyright 2009, Red Hat Middleware LLC, and others contributors as indicated
- * by the @authors tag. All rights reserved.
- * See the copyright.txt in the distribution for a
- * full listing of individual contributors.
- * This copyrighted material is made available to anyone wishing to use,
- * modify, copy, or redistribute it subject to the terms and conditions
- * of the GNU Lesser General Public License, v. 2.1.
- * This program is distributed in the hope that it will be useful, but WITHOUT A
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
- * PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
- * You should have received a copy of the GNU Lesser General Public License,
- * v.2.1 along with this distribution; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
- * MA 02110-1301, USA.
- */
-package org.jboss.soa.bpel.runtime.engine;
-
-import javax.xml.namespace.QName;
-
-import org.w3c.dom.Element;
-
-/**
- * This exception represents a BPEL fault returns as the result of
- * an invocation on a service.
- *
- * @author gbrown
- *
- */
-public class BPELFault extends Exception {
-
- private static final long serialVersionUID = 5232665438135478453L;
-
- /**
- * This constructor initialises the BPEL fault with a qualified
- * name and the fault message content.
- *
- * @param faultName The fault name
- * @param faultMesg The fault message
- */
- public BPELFault(QName faultName, Element faultMesg) {
- super("BPEL Fault '"+faultName+"'");
-
- m_faultName = faultName;
- m_faultMesg = faultMesg;
- }
-
- /**
- * This method returns the full qualified name of the
- * fault.
- *
- * @return The fault name
- */
- public QName getFaultName() {
- return(m_faultName);
- }
-
- /**
- * This method returns the fault message content.
- *
- * @return The fault message
- */
- public Element getFaultMessage() {
- return(m_faultMesg);
- }
-
- private QName m_faultName=null;
- private Element m_faultMesg=null;
-}
Modified: trunk/runtime/engine/src/main/java/org/jboss/soa/bpel/runtime/engine/PartnerChannel.java
===================================================================
--- trunk/runtime/engine/src/main/java/org/jboss/soa/bpel/runtime/engine/ode/BPELEngineImpl.java 2009-11-23 16:52:29 UTC (rev 302)
+++ trunk/runtime/engine/src/main/java/org/jboss/soa/bpel/runtime/engine/ode/BPELEngineImpl.java 2009-11-23 17:38:28 UTC (rev 303)
@@ -39,7 +39,6 @@
import org.apache.ode.utils.GUID;
import org.apache.ode.utils.Properties;
import org.jboss.soa.bpel.runtime.engine.BPELEngine;
-import org.jboss.soa.bpel.runtime.engine.BPELFault;
import org.jboss.soa.bpel.runtime.engine.IntegrationLayer;
import org.jboss.soa.bpel.runtime.engine.InvocationAdapter;
import org.w3c.dom.Element;
@@ -92,7 +91,7 @@
* @throws Exception Failed to invoke the operation
*/
public void invoke(InvocationAdapter invocationAdapter)
- throws BPELFault, Exception
+ throws Exception
{
boolean success = true;
MyRoleMessageExchange odeMex = null;
@@ -185,10 +184,6 @@
commit = true;
- } catch (BPELFault af) {
- __log.warn("MEX produced a fault " + odeMex, af);
- commit = true;
- throw af;
} catch (Exception e) {
__log.error("Error processing response for MEX " + odeMex, e);
throw new Exception("An exception occured when invoking ODE.", e);
@@ -230,7 +225,7 @@
return odeMex;
}
- private void onResponse(MyRoleMessageExchange mex, InvocationAdapter invocationAdapter) throws BPELFault, Exception {
+ private void onResponse(MyRoleMessageExchange mex, InvocationAdapter invocationAdapter) throws Exception {
Element ret=null;
switch (mex.getStatus()) {
@@ -239,7 +234,6 @@
__log.debug("Fault response message: " + mex.getFault());
invocationAdapter.createFault(mex);
- // throw new BPELFault(mex.getFault(), mex.getFaultResponse().getMessage());
break;
case ASYNC:
case RESPONSE:
Modified: trunk/runtime/engine/src/main/java/org/jboss/soa/bpel/runtime/ws/WebServiceClient.java
===================================================================
--- trunk/runtime/engine/src/main/java/org/jboss/soa/bpel/runtime/ws/WebServiceClient.java 2009-11-23 16:52:29 UTC (rev 302)
+++ trunk/runtime/engine/src/main/java/org/jboss/soa/bpel/runtime/ws/WebServiceClient.java 2009-11-23 17:38:28 UTC (rev 303)
@@ -28,7 +28,6 @@
import org.apache.ode.bpel.iapi.PartnerRoleMessageExchange;
import org.apache.ode.bpel.iapi.Scheduler;
import org.apache.ode.utils.DOMUtils;
-import org.jboss.soa.bpel.runtime.engine.BPELFault;
import org.jboss.soa.bpel.runtime.engine.EndpointReference;
import org.jboss.soa.bpel.runtime.engine.PartnerChannel;
import org.jboss.soa.bpel.runtime.engine.ode.ExecutionEnvironment;
@@ -252,7 +251,7 @@
return tx;
}
- public Element invoke(String operation, Element mesg) throws BPELFault
+ public Element invoke(String operation, Element mesg) throws Exception
{
throw new RuntimeException("Not implemented. Should be removed form interface");
}
Modified: trunk/runtime/jbossesb-bpel/src/test/java/org/jboss/soa/esb/actions/bpel/BPELInvokeTest.java
===================================================================
--- trunk/runtime/jbossesb-bpel/src/test/java/org/jboss/soa/esb/actions/bpel/BPELInvokeTest.java 2009-11-23 16:52:29 UTC (rev 302)
+++ trunk/runtime/jbossesb-bpel/src/test/java/org/jboss/soa/esb/actions/bpel/BPELInvokeTest.java 2009-11-23 17:38:28 UTC (rev 303)
@@ -17,7 +17,6 @@
*/
package org.jboss.soa.esb.actions.bpel;
-import org.jboss.soa.bpel.runtime.engine.BPELFault;
import org.jboss.soa.esb.helpers.ConfigTree;
import org.jboss.soa.esb.message.Message;
import org.jboss.soa.esb.message.format.MessageFactory;
Modified: trunk/runtime/jbossesb-bpel/src/test/java/org/jboss/soa/esb/actions/bpel/TestBPELEngine.java
===================================================================
--- trunk/runtime/jbossesb-bpel/src/test/java/org/jboss/soa/esb/actions/bpel/TestBPELEngine.java 2009-11-23 16:52:29 UTC (rev 302)
+++ trunk/runtime/jbossesb-bpel/src/test/java/org/jboss/soa/esb/actions/bpel/TestBPELEngine.java 2009-11-23 17:38:28 UTC (rev 303)
@@ -19,7 +19,6 @@
import org.jboss.soa.bpel.runtime.engine.BPELEngine;
-import org.jboss.soa.bpel.runtime.engine.BPELFault;
import org.jboss.soa.bpel.runtime.engine.IntegrationLayer;
import org.jboss.soa.bpel.runtime.engine.InvocationAdapter;
import org.w3c.dom.Document;
@@ -71,7 +70,7 @@
}
public void invoke(InvocationAdapter invocationAdapter)
- throws BPELFault, Exception {
+ throws Exception {
ESBInvocationAdapter esbCtx = (ESBInvocationAdapter) invocationAdapter;
m_request = esbCtx.getRequestXML();
15 years, 3 months
--- trunk/runtime/engine/src/main/java/org/jboss/soa/bpel/runtime/engine/PartnerChannel.java 2009-11-23 16:52:29 UTC (rev 302)
+++ trunk/runtime/engine/src/main/java/org/jboss/soa/bpel/runtime/engine/PartnerChannel.java 2009-11-23 17:38:28 UTC (rev 303)
@@ -45,11 +45,11 @@
* @param operation The operation name
* @param mesg The message
* @return The optional response
* @throws BPELFault The optional fault
* @deprecated use {@link #invoke(org.apache.ode.bpel.iapi.PartnerRoleMessageExchange)} instead
*/
public org.w3c.dom.Element invoke(String operation, org.w3c.dom.Element mesg)
- throws BPELFault;
+ throws Exception;
void invoke(PartnerRoleMessageExchange mex);
Modified: trunk/runtime/engine/src/main/java/org/jboss/soa/bpel/runtime/engine/ode/BPELEngineImpl.java
===================================================================
@@ -45,11 +45,11 @@
* @param mesg The message
* @return The optional response
- * @throws BPELFault The optional fault
+ * @throws Exception The optional fault
* @deprecated use {@link #invoke(org.apache.ode.bpel.iapi.PartnerRoleMessageExchange)} instead
*/